<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Current Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <comment>Please replace &apos;None&apos; with the language of your translation</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information on how to translate KeePassX can be found under:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developer, Project Admin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web Designer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thanks To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Patches for better MacOS X support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Application Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Various fixes and improvements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make sure that the program is installed correctly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AppName</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AppFunc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>http://keepassx.sourceforge.net</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>keepassx@gmail.com</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright (C) 2005 - 2009 KeePassX Team
KeePassX is distributed under the terms of the
General Public License (GPL) version 2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Credits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDlg</name>
    <message>
        <source>Add Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoTypeDlg</name>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KeePassX - Auto-Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click on an entry to auto-type it.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CDbSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AES(Rijndael):  256 Bit   (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please determine the number of encryption rounds.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&apos;%1&apos; is not valid integer value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The number of encryption rounds have to be greater than 0.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CEditEntryDlg</name>
    <message>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 Weeks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Weeks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6 Months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calendar...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password and password repetition are not equal.
Please check your input.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[Untitled Entry]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Attachment...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The chosen entry has no attachment or it is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Attachment...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while writing the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Attachment?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are about to delete the attachment of this entry.
Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No, Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CGenPwDialog</name>
    <message>
        <source>Password Generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Bits</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CSelectIconDlg</name>
    <message>
        <source>Replace...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Custom Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Icons...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: File could not be loaded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while loading the icon(s):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while loading the icon.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CSettingsDlg</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a directory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an executable...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System Language</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CalendarDialog</name>
    <message>
        <source>Calendar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CollectEntropyDlg</name>
    <message>
        <source>Entropy Collection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Number Generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collecting entropy...
Please move the mouse and/or press some keys until enought entropy for a reseed of the random number generator is collected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; color:#006400;&quot;&gt;Random pool successfully reseeded!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CustomizeDetailViewDialog</name>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attachment Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Access Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Modification Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expiration Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time till Expiration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rich Text Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underlined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left-Aligned</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Centered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right-Aligned</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Justified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>14</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>18</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>20</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>24</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>26</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>28</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>36</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>42</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>78</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Database</name>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsDlg</name>
    <message>
        <source>Database Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption Rounds:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculate rounds for a 1-second delay on this computer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DetailViewTemplate</name>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Modification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expiration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEntryDialog</name>
    <message>
        <source>Edit Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ge&amp;n.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attachment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditGroupDialog</name>
    <message>
        <source>Group Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExpiredEntriesDialog</name>
    <message>
        <source>Expired Entries in the Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expired Entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Double click on an entry to jump to it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expired</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Export_KeePassX_Xml</name>
    <message>
        <source>XML Files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KeePassX XML File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Export_Txt</name>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Files (*.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExporterBase</name>
    <message>
        <source>Export File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileErrors</name>
    <message>
        <source>No error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occurred while reading from the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occurred while writing to the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A fatal error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An resource error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file could not be opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The operation was aborted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A timeout occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An unspecified error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file could not be removed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file could not be renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The position in the file could not be changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file could not be resized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file could not be copied.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GenPwDlg</name>
    <message>
        <source>Password Generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use following character groups:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Lower Letters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;White Spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Upper Letters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Special Characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ensure that password contains characters from every group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pronounceable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower Letters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upper Letters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the following characters:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable entropy collection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collect only once per session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HelpDlg</name>
    <message>
        <source>Help Contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First Page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Import_KWalletXml</name>
    <message>
        <source>XML Files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid XML file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document does not contain data.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Import_KeePassX_Xml</name>
    <message>
        <source>KeePass XML Files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML parsing error on line %1 column %2:
%3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parsing error: File is no valid KeePassX XML file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Import_PwManager</name>
    <message>
        <source>PwManager Files (*.pwm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File is no valid PwManager file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported file version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported hash algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compressed files are not supported yet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wrong password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File is damaged (hash test failed).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid XML data (see stdout for details).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImporterBase</name>
    <message>
        <source>Import File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kdb3Database</name>
    <message>
        <source>Could not open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected file size (DB_TOTAL_SIZE &lt; DB_HEADER_SIZE)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wrong Signature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported File Version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Encryption Algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to initialize the twofish algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown encryption algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decryption failed.
The key is wrong or the file is damaged.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hash test failed.
The key is wrong or the file is damaged.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected error: Offset is out of range.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid group tree.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key file is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The database must contain at least one group.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The database has been opened read-only.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kdb3Database::EntryHandle</name>
    <message>
        <source>Bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GiB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeepassEntryView</name>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attachment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this entry?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete these %1 entries?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At least one group must exist before adding an entry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeepassGroupView</name>
    <message>
        <source>Search Results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this group, all its child groups and all their entries?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeepassMainWindow</name>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift+Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift+Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The database file does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The database you are trying to open is locked.
This means that either someone else has opened the file or KeePassX crashed last time it opened the database.

Do you want to open it anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error while loading database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following error occured while opening the database:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save modified file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The current file was modified.
Do you want to save the changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t remove database lock file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KeePass Databases (*.kdb)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expired</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Months</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Years</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>less than 1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clone Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clone Entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File could not be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t create database lock file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Un&amp;lock Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t create lock file. Opening the database read-only.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>new</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>locked</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File &apos;%1&apos; could not be found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>KeePassX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Export to...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Import from...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar &amp;Icon Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Columns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xtras</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Manage Bookmarks...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open Database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Database &amp;As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Database Settings...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change &amp;Master Key...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Lock Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add New Subgroup...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit Group...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Password &amp;to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy &amp;Username to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save Attachment As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &amp;New Entry...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View/Edit Entry...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>De&amp;lete Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clone Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search &amp;in Database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search in this &amp;Group...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;Entry Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide &amp;Usernames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide &amp;Passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User&amp;name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xpires</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;reation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Last Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last &amp;Access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A&amp;ttachment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;Statusbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;KeePassX Handbook...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Perform AutoType</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;16x16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;22x22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2&amp;8x28</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Password Generator...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;Expired Entries...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recycle Bin...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add Bookmark...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmark &amp;this Database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy URL to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add New Group...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minimize Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageBookmarksDlg</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Enter Master Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Master Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Master Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Key File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key Files (*.key)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter a Password or select a key file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter a Password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please provide a key file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1:
No such file or directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected key file or directory is not readable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The given directory does not contain any key files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The given directory contains more then one key files.
Please specify the key file directly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1:
File is not readable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDlg</name>
    <message>
        <source>Last File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a Password and/or choose a key file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate Key File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please repeat your password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Passwords are not equal.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Search_Dlg</name>
    <message>
        <source>Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass&amp;words</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A&amp;nhang</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>U&amp;RLs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;omments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Usernames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Titles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Case Sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Regular E&amp;xpression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include Subgroups (recursive)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search For:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectIconDlg</name>
    <message>
        <source>Icon Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General (1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General (2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show system tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimize to tray instead of taskbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimize to tray when clicking the main window&apos;s close button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember last opened file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember last key type and location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save recent directories of file dialogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear History Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always ask before deleting entries or groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save backups of modified entries into the &apos;Backup&apos; group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete backup entries older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically save database on exit and workspace locking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically save database after every change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Banner Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;hange...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show window always on top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternating Row Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize Entry Detail View...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group tree at start-up:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore last state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expand all items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not expand any item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show plain text passwords in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Entry Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database Key Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear clipboard after:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock workspace when minimizing the main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock database after inactivity of</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Browser Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Root:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The directory where storage devices like CDs and memory sticks are normally mounted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable this if you want to use your bookmarks and the last opened file independet from their absolute paths. This is especially useful when using KeePassX portably and therefore with changing mount points in the file system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save relative paths (bookmarks and last file)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Type Fine Tuning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time between the activation of an auto-type action by the user and the first simulated key stroke.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pre-Gap:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key Stroke Delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay between two simulated key strokes. Increase this if Auto-Type is randomly skipping characters.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global Auto-Type Shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use entries&apos; title to match the window for Global Auto-Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can disable several features of KeePassX here according to your needs in order to keep the user interface slim.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plug-Ins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gnome Desktop Integration (Gtk 2.x)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KDE 4 Desktop Integration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You need to restart the program before the changes take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutWidget</name>
    <message>
        <source>Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AltGr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Win</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SimplePasswordDialog</name>
    <message>
        <source>Enter your Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TargetWindowDlg</name>
    <message>
        <source>Auto-Type: Select Target Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To specify the target window, either select an existing currently-opened window
from the drop-down list, or enter the window title manually:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Translation</name>
    <message>
        <source>$TRANSLATION_AUTHOR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>$TRANSLATION_AUTHOR_EMAIL</source>
        <comment>Here you can enter your email or homepage if you want.</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>$LANGUAGE_NAME</source>
        <comment>Insert your language name in the format: English (United States)</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WorkspaceLockedWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Verdana&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;The workspace is locked.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
